# What is Patternslib?

Patternslib is a library of reusable patterns which let you create rich,
dynamic and interactive prototypes or websites, without having to know or care about Javascript.

Instead of writing or integrating Javascript, you simply add special CSS classes and HTML5 data attributes to your HTML.
These classes and `data-` attributes describe the so-called "interaction patterns" of Patternslib.
